Ancrer les fenêtres utilisateur
===============================

Quand on développe son programme Turtle (ou utilisant Tkinter), on peut vouloir regarder la fenêtre
de l'essai précédent tout en réparant quelques lignes de code. Si on a des écrans de grande taille ou nombreux,
ce n'est pas difficile de placer cette fenêtre près de celle de turcar,
mais au lancement suivant, le gestionnaire de fenêtre peut la replacer n'importe où et il faut
remettre en place à nouveau les fenêtres.

**Ancrer les fenêtres utilisateur** dans le **menu Lancer** est prévu pour vous aider dans cette situation. Si vous
cochez cette option et que vous lancez votre programme Tkinter, turcar réaliser la magie suivante :

* Il se souvient des emplacements de vos fenêtres. Les fois suivantes il place les fenêtres à la même position.
* Il fait en sorte que votre fenêtre reste au-dessus même si on clique sur la fenêtre turcar pour commencer à modifier le code. En fait, après que la fenêtre Tkinter est apparue, turcar met automatiquement le focus sur sa propre fenêtre si bien que vous pouvez continuer à éditer le code sans utiliser la souris. Quand on a fini, il suffit d'appuyer à nouveau sur F5 et l'ancienne fenêtre est remplacée par la nouvelle.
 
 
